@@ -1,5 +1,5 @@
 full <-
-function(x=NULL)  {
+function(x=mydata)  {
 
   dashes <- function(ndash, cc) { for (i in 1:(ndash)) cat(cc); cat("\n") }
 
@@ -12,22 +12,16 @@ function(x=NULL)  {
   cat(format(Sys.time(), "%a %b %d, %Y at %H:%M"), "\n")
   dashes(25,"-")
 
-  cat("\n\n\n")
-  dashes(29,"+")
-  cat("Data Summary of Each Variable\n")
-  dashes(29,"+")
-  describe(x)
-
   cat("\n\n\n")
   dashes(37,"+")
   cat("Histogram for Each Numerical Variable\n")
   dashes(37,"+")
-  color.hist(x)
+  hst(dframe=x)
   
   cat("\n\n\n")
   dashes(39,"+")
   cat("Bar Chart for Each Non-numeric Variable\n")
   dashes(39,"+")
-  color.barchart(x)
+  bc(dframe=x)
   
 }
